==> ec-rider0.8.1.tar.gz: ec-rider0.8.1/ec_admin/spec/controllers/cms_files_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe CmsFilesController do
  fixtures :cms_files, :cms_projects

  def login_as_admin
    login_as("admin")
    session[:project_id] = cms_projects(:cms_projects_00001).id
  end

  describe "GET index" do
    it "should get index" do
      login_as_admin
      get :index
      response.should be_success
      assigns("cms_files").should_not be_nil
    end
  end

  describe "POST create" do
    before(:each) do
      EcRider.config.stub!(:s3_access_key_id).and_return(nil)
      tmp_dir = File.expand_path(File.join(Dir.tmpdir, "test_cms_real_files"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'public', 'cms'))
      EcRider.config.stub!(:ec_admin_root).and_return(tmp_dir)
    end

    it "should create directory" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/cms_test", :child_dir => "new_sub_dir"}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(1)
      flash[:error].should be_nil
    end

    it "should not create directory(ディレクトリ名未入力)" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/", :child_dir => ""}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(0)
      flash[:error].should be_nil
    end

    it "should not create directory(半角文字以外が含まれるディレクトリ名)" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/", :child_dir => "新ディレクトリ"}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(0)
      flash[:error].should_not be_nil
    end

    it "should not create directory(禁止されているディレクトリ名)" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/", :child_dir => "ec_rider"}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(0)
      flash[:error].should_not be_nil
    end

    it "should upload new file" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_files/common/logo.GIF"
      uploaded_file_path = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'cms', 'logo.GIF'))
      FileUtils.rm_rf(uploaded_file_path)
      File.exist?(uploaded_file_path).should == false # まだアップロードされていない

      open(fixture_file_path) do |up_file|
        up_file.should_receive(:original_path).exactly(2).and_return(fixture_file_path)
        up_file.should_receive(:original_filename).exactly(1).and_return(File.basename(fixture_file_path))
        post(:create, {:parent_dir => "public/cms", :upload_file => up_file, :overwrite => true})
      end

      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should == true # アップロードされた

      # ファイルの中身もバッチリ一緒
      IO.read(uploaded_file_path).should == IO.read(fixture_file_path)
    end

    it "公開時に削除" do
      login_as_admin
      session[:project_id] = cms_projects(:cms_projects_00004).id
      lambda {
        post(:create, :source_id => 76)
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(1)
      created_file = CmsFile.find(:first,
        :conditions => ["public_file_path = ? and cms_project_id = ?", "public/javascripts/prototype.js", cms_projects(:cms_projects_00004).id])
      created_file.delete_at_publish.should be_true
    end

    it "ファイルのZIP" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/test_cms_real_files/text.zip"
      uploaded_file_path = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'zip_file', 'text.txt'))
      FileUtils.rm_rf(uploaded_file_path)
      File.exist?(uploaded_file_path).should == false # まだアップロードされていない
      post(:create, {:parent_dir => "public/", :child_dir => "zip_file"})
      dir_cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/zip_file/"])
      dir_cms_files.length.should == 1
      dir_cms_files[0].cms_project_id.should == nil

      open(fixture_file_path) do |up_file|
        up_file.should_receive(:original_path).exactly(2).and_return(fixture_file_path)
        up_file.should_receive(:original_filename).exactly(1).and_return(File.basename(fixture_file_path))
        post(:create, {:parent_dir => "public/zip_file/", :upload_file => up_file, :overwrite => true})
      end

      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should == true # アップロードされた

      dir_cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/zip_file/"])
      dir_cms_files.length.should == 1
      dir_cms_files[0].cms_project_id.should == nil
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/zip_file/text.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
    end

    it "ディレクトリのZIP" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/test_cms_real_files/updir.zip"
      uploaded_file_path1 = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'updir', 'text.txt'))
      uploaded_file_path2 = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'updir', 'text2.txt'))
      uploaded_file_path3 = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'updir', 'text3.txt'))
      FileUtils.rm_rf(uploaded_file_path1)
      FileUtils.rm_rf(uploaded_file_path2)
      FileUtils.rm_rf(uploaded_file_path3)
      File.exist?(uploaded_file_path1).should == false # まだアップロードされていない
      File.exist?(uploaded_file_path2).should == false # まだアップロードされていない
      File.exist?(uploaded_file_path2).should == false # まだアップロードされていない

      open(fixture_file_path) do |up_file|
        up_file.should_receive(:original_path).exactly(2).and_return(fixture_file_path)
        up_file.should_receive(:original_filename).exactly(1).and_return(File.basename(fixture_file_path))
        post(:create, {:parent_dir => "public/", :upload_file => up_file, :overwrite => true})
      end

      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path1).should == true # アップロードされた
      File.exist?(uploaded_file_path2).should == true # アップロードされた
      File.exist?(uploaded_file_path3).should == true # アップロードされた

      dir_cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/"])
      dir_cms_files.length.should == 1
      dir_cms_files[0].cms_project_id.should == nil
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/text.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/text2.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/text3.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
    end
  end

  describe "DELETE destroy" do
    it "削除取消" do
      login_as_admin
      session[:project_id] = cms_projects(:cms_projects_00004).id
      CmsFile.create(:public_file_path => 'public/javascripts/prototype.js', :cms_project_id => cms_projects(:cms_projects_00004).id, :delete_at_publish => true)
      lambda {
        delete(:destroy, :source_id => 76)
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(-1)
      created_file = CmsFile.find(:first,
        :conditions => ["public_file_path = ? and cms_project_id = ?", "public/javascripts/prototype.js", cms_projects(:cms_projects_00004).id])
      created_file.should be_nil
    end
  end

end

==> ec-rider0.8.2.tar.gz: ec-rider0.8.2/ec_admin/spec/controllers/cms_files_controller_spec.rb <==
# -*- coding: utf-8 -*-
require File.join(File.dirname(__FILE__), '..', 'spec_helper')

describe CmsFilesController do
  fixtures :cms_files, :cms_projects

  def login_as_admin
    login_as("admin")
    session[:project_id] = cms_projects(:cms_projects_00001).id
  end

  describe "GET index" do
    it "should get index" do
      login_as_admin
      get :index
      response.should be_success
      assigns("cms_files").should_not be_nil
    end

    it "should search" do
      CmsFile.create(:public_file_path => 'public/test_dir/', :cms_project_id => cms_projects(:cms_projects_00001).id)
      login_as_admin
      get(:index, :condition => {:edit_target => '1'})
      response.should be_success
      assigns("cms_files").should_not be_nil
    end
  end

  describe "POST create" do
    before(:each) do
      EcRider.config.stub!(:s3_access_key_id).and_return(nil)
      tmp_dir = File.expand_path(File.join(RAILS_ROOT, "tmp", "test_cms_real_files"))
      Dir.glob(File.join(tmp_dir, '*')) .each{|f| FileUtils.rm_rf(f) }
      FileUtils.mkdir_p(File.join(tmp_dir, 'public', 'cms'))
      EcRider.config.stub!(:ec_admin_root).and_return(tmp_dir)
    end

    it "should create directory" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/cms_test", :child_dir => "new_sub_dir"}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(1)
      flash[:error].should be_nil
    end

    it "should not create directory(ディレクトリ名未入力)" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/", :child_dir => ""}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(0)
      flash[:error].should be_nil
    end

    it "should not create directory(半角文字以外が含まれるディレクトリ名)" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/", :child_dir => "新ディレクトリ"}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(0)
      flash[:error].should_not be_nil
    end

    it "should not create directory(禁止されているディレクトリ名)" do
      login_as_admin
      lambda {
        post :create, {:parent_dir => "public/", :child_dir => "ec_rider"}
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(0)
      flash[:error].should_not be_nil
    end

    it "should upload new file" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/cms_files/common/logo.GIF"
      uploaded_file_path = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'cms', 'logo.GIF'))
      FileUtils.rm_rf(uploaded_file_path)
      File.exist?(uploaded_file_path).should == false # まだアップロードされていない

      open(fixture_file_path) do |up_file|
        up_file.should_receive(:original_path).exactly(2).and_return(fixture_file_path)
        up_file.should_receive(:original_filename).exactly(1).and_return(File.basename(fixture_file_path))
        post(:create, {:parent_dir => "public/cms", :upload_file => up_file, :overwrite => true})
      end

      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should == true # アップロードされた

      # ファイルの中身もバッチリ一緒
      IO.read(uploaded_file_path).should == IO.read(fixture_file_path)
    end

    it "公開時に削除" do
      login_as_admin
      session[:project_id] = cms_projects(:cms_projects_00004).id
      lambda {
        post(:create, :source_id => 76)
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(1)
      created_file = CmsFile.find(:first,
        :conditions => ["public_file_path = ? and cms_project_id = ?", "public/javascripts/prototype.js", cms_projects(:cms_projects_00004).id])
      created_file.delete_at_publish.should be_true
    end

    it "ファイルのZIP" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/test_cms_real_files/text.zip"
      uploaded_file_path = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'zip_file', 'text.txt'))
      FileUtils.rm_rf(uploaded_file_path)
      File.exist?(uploaded_file_path).should == false # まだアップロードされていない
      post(:create, {:parent_dir => "public/", :child_dir => "zip_file"})
      dir_cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/zip_file/"])
      dir_cms_files.length.should == 1
      dir_cms_files[0].cms_project_id.should == nil

      open(fixture_file_path) do |up_file|
        up_file.should_receive(:original_path).exactly(2).and_return(fixture_file_path)
        up_file.should_receive(:original_filename).exactly(1).and_return(File.basename(fixture_file_path))
        post(:create, {:parent_dir => "public/zip_file/", :upload_file => up_file, :overwrite => true})
      end

      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path).should == true # アップロードされた

      dir_cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/zip_file/"])
      dir_cms_files.length.should == 1
      dir_cms_files[0].cms_project_id.should == nil
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/zip_file/text.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
    end

    it "ディレクトリのZIP" do
      login_as_admin

      fixture_file_path = "#{RAILS_ROOT}/test/fixtures/test_cms_real_files/updir.zip"
      uploaded_file_path1 = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'updir', 'text.txt'))
      uploaded_file_path2 = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'updir', 'text2.txt'))
      uploaded_file_path3 = File.expand_path(File.join(EcRider.config.ec_admin_root, 'public', 'projects', '1', 'public', 'updir', 'text3.txt'))
      FileUtils.rm_rf(uploaded_file_path1)
      FileUtils.rm_rf(uploaded_file_path2)
      FileUtils.rm_rf(uploaded_file_path3)
      File.exist?(uploaded_file_path1).should == false # まだアップロードされていない
      File.exist?(uploaded_file_path2).should == false # まだアップロードされていない
      File.exist?(uploaded_file_path2).should == false # まだアップロードされていない

      open(fixture_file_path) do |up_file|
        up_file.should_receive(:original_path).exactly(2).and_return(fixture_file_path)
        up_file.should_receive(:original_filename).exactly(1).and_return(File.basename(fixture_file_path))
        post(:create, {:parent_dir => "public/", :upload_file => up_file, :overwrite => true})
      end

      response.should redirect_to(:action => 'index')
      File.exist?(uploaded_file_path1).should == true # アップロードされた
      File.exist?(uploaded_file_path2).should == true # アップロードされた
      File.exist?(uploaded_file_path3).should == true # アップロードされた

      dir_cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/"])
      dir_cms_files.length.should == 1
      dir_cms_files[0].cms_project_id.should == nil
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/text.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/text2.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
      cms_files = CmsFile.find(:all, :conditions => ["public_file_path = ?", "public/updir/text3.txt"])
      cms_files.length.should == 1
      cms_files[0].cms_project_id.should == 1
    end
  end

  describe "DELETE destroy" do
    it "削除取消" do
      login_as_admin
      session[:project_id] = cms_projects(:cms_projects_00004).id
      CmsFile.create(:public_file_path => 'public/javascripts/prototype.js', :cms_project_id => cms_projects(:cms_projects_00004).id, :delete_at_publish => true)
      lambda {
        delete(:destroy, :source_id => 76)
        response.should redirect_to(:action => 'index')
      }.should change(CmsFile, :count).by(-1)
      created_file = CmsFile.find(:first,
        :conditions => ["public_file_path = ? and cms_project_id = ?", "public/javascripts/prototype.js", cms_projects(:cms_projects_00004).id])
      created_file.should be_nil
    end
  end

end
